function [AP, APA, APS, GA, BFI, KS, SS, JS] = skatt2000(FFI, AI, PBB, MA, KI, SG1, SG2,  SI, SV)
%SKATT2000 Skattesystemet fr inkomstskatteret 2000
%   FFI              Faststlld frvrvsinkomst
%   AI               Arbetsinkomst (grund fr jobbskatteavdraget)
%   PBB              Prisbasbelopp
%   MA               Maximal avgift till allmn pension
%   KI               Kommunal inkomstskatt, procent
%   SG1              Skiktgrns 1, nedre
%   SG2              Skiktgrns 2, vre
%   SI               Statlig inkomstskatt, procent
%   SV               Statlig vrnskatt, procent

%   AP               Allmn pensionsavgift
%   APA              Avdrag fr allmn pensionsavgift
%   APS              Skattereduktion fr allmn pensionsavgift
%   GA               Grundavdraget
%   BFI              Beskattningsbar frvrvsinkomst
%   KS               Kommunal skatt
%   SS               Statlig skatt
%   JS               Jobbskatteavdraget

% Berkna allmn pensionsavgift, AP
if FFI < 0.24*PBB
    AP = 0;
else
    AP = min(FFI*0.07, MA);
end

% Berkna avdrag (APA) och skattereduktion (APS) fr allmn pensionsavgift
APA = 0.75 * AP;
APS = 0.25 * AP;

% Berkna grundavdraget, GA
if FFI < 1.86*PBB
    GA = 0.24*PBB;
elseif FFI < 2.89*PBB
    GA = 0.24*PBB + 0.25*(FFI-1.86*PBB);
elseif FFI < 3.04*PBB
    GA = 0.4975*PBB;
elseif FFI < 5.615*PBB
    GA = 0.4975*PBB - 0.1*(FFI-3.04*PBB);
else
    GA = 0.24*PBB;
end
GA = min(GA,FFI);  %Grundavdraget kan inte vara strre n FFI

% Berkna beskattningsbar frvrvsinkomst, BFI
BFI = max(FFI-GA-APA,0);

% Berkna kommunal skatt, KS
KS = BFI*KI;

% Berkna statlig skatt, SS
if BFI < SG1
    SS = 0;
elseif BFI < SG2
    SS = (BFI-SG1)*SI;
else
    SS = (BFI-SG1)*SI + (BFI-SG2)*(SV);
end

% Berkna jobbskatteavdraget, JS
JS = 0;  % Jobbskatteavdraget infrdes senare

end

