function [AP, APA, APS, GA, BFI, KS, SS, JS] = skatt2019(FFI, AI, PBB, MA, KI, SG1, SG2,  SI, SV)
%SKATT2019 Skattesystemet fr inkomstskatteret 2019
%   FFI              Faststlld frvrvsinkomst
%   AI               Arbetsinkomst (grund fr jobbskatteavdraget)
%   PBB              Prisbasbelopp
%   MA               Maximal avgift till allmn pension
%   KI               Kommunal inkomstskatt, procent
%   SG1              Skiktgrns 1, nedre
%   SG2              Skiktgrns 2, vre
%   SI               Statlig inkomstskatt, procent
%   SV               Statlig vrnskatt, procent

%   AP               Allmn pensionsavgift
%   APA              Avdrag fr allmn pensionsavgift
%   APS              Skattereduktion fr allmn pensionsavgift
%   GA               Grundavdraget
%   BFI              Beskattningsbar frvrvsinkomst
%   KS               Kommunal skatt
%   SS               Statlig skatt
%   JS               Jobbskatteavdraget

% Berkna allmn pensionsavgift, AP
if FFI < 0.423*PBB
    AP = 0;
else
    AP = min(FFI*0.07, MA);
end

% Berkna avdrag (APA) och skattereduktion (APS) fr allmn pensionsavgift
APA = 0.00 * AP;
APS = 1.00 * AP;

% Berkna grundavdraget, GA
if FFI < 0.99*PBB
    GA = 0.423*PBB;
elseif FFI < 2.72*PBB
    GA = 0.225*PBB + 0.2*FFI;
elseif FFI < 3.11*PBB
    GA = 0.770*PBB;
elseif FFI < 7.88*PBB
    GA = 1.081*PBB - 0.1*FFI;
else
    GA = 0.293*PBB;
end
GA = min(GA,FFI);  %Grundavdraget kan inte vara strre n FFI

% Berkna beskattningsbar frvrvsinkomst, BFI
BFI = max(FFI-GA-APA,0);

% Berkna kommunal skatt, KS
KS = BFI*KI;

% Berkna statlig skatt, SS
if BFI < SG1
    SS = 0;
elseif BFI < SG2
    SS = (BFI-SG1)*SI;
else
    SS = (BFI-SG1)*SI + (BFI-SG2)*(SV);
end

% Berkna jobbskatteavdraget, JS
if AI < 0.91*PBB
    JS = (AI-GA)*KI;
elseif AI < 3.24*PBB
    JS = (0.91*PBB+0.3405*(AI-0.91*PBB)-GA)*KI;
elseif AI < 8.08*PBB
    JS = (1.703*PBB+0.128*(AI-3.24*PBB)-GA)*KI;
elseif AI < 13.54*PBB
    JS = (2.323*PBB-GA)*KI;
else
    JS = (2.323*PBB-GA)*KI-0.03*(AI-13.54*PBB);
end
JS = max(JS,0);  % Jobbskatteavdraget kan inte vara negativt

end

